@@ -10,11 +10,12 @@ from netqasm.backend.messages import (
     SubroutineMessage,
 )
 from netqasm.logging.glob import get_netqasm_logger
+from netqasm.sdk.build_types import GenericHardwareConfig, HardwareConfig
 from netqasm.sdk.builder import Builder
 from netqasm.sdk.connection import (
     BaseNetQASMConnection,
     NetworkInfo,
-    PreSubroutine,
+    ProtoSubroutine,
     T_Message,
 )
 from netqasm.sdk.shared_memory import SharedMemory
@@ -28,7 +29,7 @@ from squidasm.run.singlethread.protocols import (
 )
 
 if TYPE_CHECKING:
-    from netqasm.sdk.compiling import SubroutineCompiler
+    from netqasm.sdk.transpile import SubroutineTranspiler
     from netqasm.sdk.epr_socket import EPRSocket
 
 from squidasm.run.singlethread.context import NetSquidNetworkInfo
@@ -39,8 +40,9 @@ class NetSquidConnection(BaseNetQASMConnection):
         self,
         app_name: str,
         max_qubits: int = 5,
+        hardware_config: Optional[HardwareConfig] = None,
         epr_sockets: Optional[List[EPRSocket]] = None,
-        compiler: Optional[Type[SubroutineCompiler]] = None,
+        compiler: Optional[Type[SubroutineTranspiler]] = None,
         **kwargs,
     ) -> None:
         self._app_name = app_name
@@ -62,10 +64,13 @@ class NetSquidConnection(BaseNetQASMConnection):
             f"{self.__class__.__name__}({self.app_name})"
         )
 
+        if hardware_config is None:
+            hardware_config = GenericHardwareConfig(max_qubits)
+
         self._builder = Builder(
             connection=self,
             app_id=self._app_id,
-            max_qubits=max_qubits,
+            hardware_config=hardware_config,
             compiler=compiler,
         )
 
@@ -119,9 +124,9 @@ class NetSquidConnection(BaseNetQASMConnection):
         )
         yield from self._wait_for_results()
 
-    def commit_subroutine(
+    def commit_protosubroutine(
         self,
-        presubroutine: PreSubroutine,
+        protosubroutine: ProtoSubroutine,
         block: bool = True,
         callback: Optional[Callable] = None,
     ) -> Generator[EventExpression, None, None]:
@@ -130,9 +135,9 @@ class NetSquidConnection(BaseNetQASMConnection):
                 yield from self._commit_open_epr_socket(sck)
                 self._epr_sck_status[sck] = True
 
-        self._logger.debug(f"Flushing presubroutine:\n{presubroutine}")
+        self._logger.debug(f"Flushing protosubroutine:\n{protosubroutine}")
 
-        subroutine = self._builder._pre_process_subroutine(presubroutine)
+        subroutine = self._builder.subrt_compile_subroutine(protosubroutine)
         self._logger.info(f"Flushing compiled subroutine:\n{subroutine}")
 
         self._commit_message(
@@ -148,12 +153,12 @@ class NetSquidConnection(BaseNetQASMConnection):
     def flush(
         self, block: bool = True, callback: Optional[Callable] = None
     ) -> Generator[EventExpression, None, None]:
-        subroutine = self._builder._pop_pending_subroutine()
+        subroutine = self._builder.subrt_pop_pending_subroutine()
         if subroutine is None:
             return
 
-        yield from self.commit_subroutine(
-            presubroutine=subroutine,
+        yield from self.commit_protosubroutine(
+            protosubroutine=subroutine,
             block=block,
             callback=callback,
         )
