@@ -4,11 +4,13 @@ import logging
 from typing import TYPE_CHECKING, Callable, Generator, Optional, Type
 
 from netqasm.backend.messages import SubroutineMessage
+from netqasm.lang.subroutine import Subroutine
+from netqasm.sdk.build_types import GenericHardwareConfig, HardwareConfig
 from netqasm.sdk.builder import Builder
 from netqasm.sdk.connection import (
     BaseNetQASMConnection,
     NetworkInfo,
-    PreSubroutine,
+    ProtoSubroutine,
     T_Message,
 )
 from netqasm.sdk.shared_memory import SharedMemory
@@ -16,7 +18,7 @@ from netqasm.sdk.shared_memory import SharedMemory
 from pydynaa import EventExpression
 
 if TYPE_CHECKING:
-    from netqasm.sdk.compiling import SubroutineCompiler
+    from netqasm.sdk.transpile import SubroutineTranspiler
     from squidasm.sim.stack.host import Host
 
 from squidasm.sim.stack.common import LogManager
@@ -31,7 +33,8 @@ class QnosConnection(BaseNetQASMConnection):
         app_id: int,
         app_name: str,
         max_qubits: int = 5,
-        compiler: Optional[Type[SubroutineCompiler]] = None,
+        hardware_config: Optional[HardwareConfig] = None,
+        compiler: Optional[Type[SubroutineTranspiler]] = None,
         **kwargs,
     ) -> None:
         self._app_name = app_name
@@ -46,10 +49,13 @@ class QnosConnection(BaseNetQASMConnection):
             f"{self.__class__.__name__}({self.app_name})"
         )
 
+        if hardware_config is None:
+            hardware_config = GenericHardwareConfig(max_qubits)
+
         self._builder = Builder(
             connection=self,
             app_id=self._app_id,
-            max_qubits=max_qubits,
+            hardware_config=hardware_config,
             compiler=compiler,
         )
 
@@ -70,17 +76,28 @@ class QnosConnection(BaseNetQASMConnection):
         self._logger.debug(f"Committing message {msg}")
         self._host.send_qnos_msg(bytes(msg))
 
-    def commit_subroutine(
+    def commit_protosubroutine(
         self,
-        presubroutine: PreSubroutine,
+        protosubroutine: ProtoSubroutine,
         block: bool = True,
         callback: Optional[Callable] = None,
     ) -> Generator[EventExpression, None, None]:
-        self._logger.info(f"Flushing presubroutine:\n{presubroutine}")
+        self._logger.info(f"Flushing protosubroutine:\n{protosubroutine}")
 
-        subroutine = self._builder._pre_process_subroutine(presubroutine)
+        subroutine = self._builder.subrt_compile_subroutine(protosubroutine)
         self._logger.info(f"Flushing compiled subroutine:\n{subroutine}")
 
+        yield from self.commit_subroutine(subroutine, block, callback)
+        self._builder._reset()
+
+    def commit_subroutine(
+        self,
+        subroutine: Subroutine,
+        block: bool = True,
+        callback: Optional[Callable] = None,
+    ) -> Generator[EventExpression, None, None]:
+        self._logger.info(f"Commiting compiled subroutine:\n{subroutine}")
+
         self._commit_message(
             msg=SubroutineMessage(subroutine=subroutine),
             block=block,
@@ -90,17 +107,15 @@ class QnosConnection(BaseNetQASMConnection):
         result = yield from self._host.receive_qnos_msg()
         self._shared_memory = result
 
-        self._builder._reset()
-
     def flush(
         self, block: bool = True, callback: Optional[Callable] = None
     ) -> Generator[EventExpression, None, None]:
-        subroutine = self._builder._pop_pending_subroutine()
+        subroutine = self._builder.subrt_pop_pending_subroutine()
         if subroutine is None:
             return
 
-        yield from self.commit_subroutine(
-            presubroutine=subroutine,
+        yield from self.commit_protosubroutine(
+            protosubroutine=subroutine,
             block=block,
             callback=callback,
         )
